.. _events:

Events
======

.. toctree::
   :maxdepth: 3

Event Types
-----------

Organizer Events
^^^^^^^^^^^^^^^^

Very useful for planning sessions, but also for support and accountability.

Python Ladies' Nights
^^^^^^^^^^^^^^^^^^^^^

The PyLadies aren’t ALL about coding -- we also love to socialize and have fun!

Hosted: a potluck/party at a member’s house
Meet: at a bar or restaurant

Workshops
^^^^^^^^^

You can host workshops either as full-day events every 1-3 months or so, or as evening events that occur weekly.

Intro to Python
***************

#. Austin PyLadies `Intro to Python`_.
#. PyStar has some great tutorials for beginners.
#. Learn Python the Hard Way by Zed Shaw
#. custom (depending on your needs)

.. _Intro to Python: <https://github.com/pyladiesatx/pyladiesatx/tree/master/classes/python_intro>

Intro to Django
***************

#. Poll tutorial from `Django Docs`_. 
#. Sandy Strong's `Intro to Django Workshop slides`_.

.. _Django Docs: http://docs.djangoproject.com
.. _Intro to Django Workshop slides: http://bit.ly/qMcEAT

Other topic of interest workshop
********************************

#. Find a programming/relevant developer book that you’d like to study. Host a weekly study group.
#. Host a weekend workshop about game programming, startups, journalism, etc.

Hackathons/Sprints
^^^^^^^^^^^^^^^^^^

LA PyLadies has hosted hackathons where attendees bring laptops and projects of their own to work on. Beginners are pointed to `learnpythonthehardway.org <http://learnpythonthehardway.org>`_ and instructed to work through the tutorial, asking for help as needed. They are urged to post exercises to Github, as a way to dip their toes in the world of open source sofware.

Hackathons can be evening, full-day, or all-weekend events.

Virtual meetups
^^^^^^^^^^^^^^^

PyLadiesAU held their first chapter meeting as a virtual meetup. See `Australian PyLadies`_ for details.

The IRC #pyladies channel is always available for anyone to use for virtual meetups. Feel free to use it without asking, or create a #pyladies-whatever channel if you prefer.

.. _Australian PyLadies: http://au.pyladies.com/events/32589162/

Meetups as part of a Python user group (PUG) meetup
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

A PyLadies event can be as simple as women getting together and talking about each others’ Python projects in a small group after a local PUG event.

Anything to encourage women to attend and continue attending PUGs is great. Talk to your local PUG organizers and ask for their help and support in having a post-PUG informal PyLadies meetup.

You might also consider trying to give a :doc:`talks/beginner` at a  meetup. This can help bring more beginners who might otherwise be  scared away to the group.

Code review sessions
^^^^^^^^^^^^^^^^^^^^

Reviewing someone’s coding project together can help everyone learn better coding practices.

Conference prep sessions
^^^^^^^^^^^^^^^^^^^^^^^^

Python conferences that might interest your chapter: PyCon, DjangoCon, PloneConf, SciPy (Python for Scientific Computing)

What you can do to prepare together:

#. Brainstorm talk ideas. Help each other put together talk outlines.
#. Review each others’ talk proposals.
#. Practice talks in front of each other, in a small group.
#. Practice in a larger group, as a joint event with the local Python user group.

Conferences can be stressful, but they’re also a lot of fun, particularly if you’re attending with a friend or a small group. There's also a good chance you will run into PyLadies from other chapters!


Event Checklist
---------------

So you’re ready to host an event?

To host an event
^^^^^^^^^^^^^^^^

* Decide the type of event.  Examples:
	* Hack night/hack weekend
	* Sprinting on an Open Source project (e.g. Django, CPython, etc)
	* Workshop - introductory Python, intermediate, intro to Git, anything
	* Study group
	* Coffee & hack
	* Speaker series/lightning talks
	* Check out ideas on other locations' websites and meetup pages.
* Email local tech companies to ask for event hosting support:
	* You can find companies that use Python by looking at their job boards, and other Python group events
	* If you're in a bigger city, choose a location that can be easily accessible via public transit, or have ample parking
	* Cold-email a general email address if you don't have an actual contact at the company.  This is still highly effective!
		* Be upfront with what you need; just hosting space?  Space and food? For how many people?
		* Include proposed dates/times
		* Offer time during the event for them to pitch their product(s) and/or any job openings
		* Ask for a description of the type of space available; feel free to ask to check it out beforehand
		* Events often need wifi for attendees, and if it's an event longer than a few hours, then easy-to-access power outlets are needed as well
		* Be mindful of the company's RSVP/check in wishes if they have any.  Do they want First & Last name? Will there be alcohol served, and therefore ID needs to be checked? 
* Once date & event is set with the host, post up the event on Meetup.com group
	* Be sure to setup the RSVP limits if space is limited.  Apprehend about 50%-60% of RSVPs will actually show up (if it's a free event).
	* Give an exact address; Meetup.com allows you to hide the address to non-group members.
	* Be *clear* on who can attend.  Women only?  Women and a guest of +1 (of either gender)? Both women and men?  Complete n00bs to Python?  Or solid Pythonistas?
	* Detail what is needed to be prepared for the event.  Just bring themselves?  Do they need their computer?  Prior knowledge?
	* Be explicit if there will be food/drinks or not so folks and plan ahead.
* If hosting a workshop, solicit for mentors.
	* Have an easy sign-up sheet for mentors (perhaps a Google Docs form).
	* Prep the mentors by detailing what you plan on doing, what your expectations are for the event, how best they can help
	* Often times, it's hard to get all-female mentors.  Most of the time, male mentors are very nice and helpful.
* A few days before the event, email RSVP'd folks to update their RSVP status if they are no longer going.  This is especially nice if folks are on a waiting list for the event.
* Arrive a little early; folks will always arrive before doors officially open
* Have nametags for attendees.  If having a workshop, have mentors where nametags and perhaps a special sticker or something to designate that they are mentors.
* Post any resources for the event - either before or afterwards.
* Have fun!

